# Documentation string. I wonder what ever refers to it?

__doc__ = """Arrow product module.

This module provides the methods and classes that Zope needs for the product. 
__init__.py is responsible for registering these methods and classes.

See README.txt for more details."""

# Version string. Usually updated automatically by CVS. 

__version__ = '1.0' # I used to wonder whether Zope checked these. Nope. 

# Now, you can compress these imports down to three lines, but that makes it 
# harder to document it as you go. Here's the long-winded version: 

from Globals import HTMLFile      # fakes a method from a DTML file
from Globals import MessageDialog # provid
from Globals import Persistent    # makes an object stick in the ZODB

import OFS.SimpleItem
import Acquisition
import AccessControl.Role

"""Step #1: Provide "constructors" for Zope's management interface.
__init__ is all very well and good for Python, but doesn't provide 
a nice HTML interface or accept arguments from an HTTP request, so 
you need to provide some functions to act as a middle-man between 
Zope and your class.

Use HTMLFile to produce a [pseudo-]function which hands back an 
appropriate DTML document based on a file sitting in your product 
directory. 
"""

manage_addArrowForm = HTMLFile('ArrowAdd', globals()) 


def manage_addArrow(self, id, body_tag='', body_arrow='', title='', trail='', color_of_trail='', text_family='', text_size='', text_spacing='', text_delay='', enable_arrow='', REQUEST=None):
    """Add an Arrow to a folder."""
    self._setObject(id, Arrow(id, body_tag,body_arrow, title,trail,color_of_trail,text_family,text_size,text_spacing,text_delay,enable_arrow))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

"""Step #2: Provide the class for your Arrow object."""

class Arrow(
    OFS.SimpleItem.Item,   # A simple Principia object. Not Folderish.
    Persistent,            # Make us persistent. Yaah!
    Acquisition.Implicit,  # Uh, whatever.
    AccessControl.Role.RoleManager # Security manager.
    ):
    """Arrow object.

    This is an attempt at writing a product from scratch using mostly
    Python instead of ZClasses. We'll see how it all goes.
    """

    meta_type = 'Arrow' # what do people think they're adding?

    manage_options = ( # what management options are there?
	{'label': 'Edit',       'action': 'manage_main'},
	{'label': 'View',       'action': ''}, # defaults to index_html
        {'label': 'Instructions',   'action': 'manage_howto'},
        {'label': 'Security',   'action': 'manage_access'},
        {'label': 'About',   'action': 'manage_about'},
        )

    __ac_permissions__=( # what permissions make sense for us?
	('View management screens', ('manage_tabs','manage_main')),
	('Change permissions',      ('manage_access',)           ),
	('Change Arrow'     ,     ('manage_edit',)             ),
	('View Arrow',            ('',)                        ),
	)

    def __init__(self, id, body_tag='', body_arrow='', title='',trail='', color_of_trail='', text_family='', text_size='', text_spacing='',text_delay='', enable_arrow=''):
        """initialise a new instance of Arrow"""
        self.id = id
        self.body_tag = HTMLFile('body_tag',globals())
        self.body_arrow = body_arrow
	self.title = title
        self.trail = trail
        self.arrow_pre =  HTMLFile('arrow_pre', globals())
        self.arrow_post =  HTMLFile('arrow_post', globals())
        self.color_of_trail = color_of_trail
        self.text_family = text_family
        self.text_size = text_size
        self.text_spacing = text_spacing
        self.text_delay = text_delay
        self.enable_arrow = enable_arrow
    index_html = HTMLFile('index', globals())

    manage_main = HTMLFile('ArrowEdit', globals())

    manage_howto = HTMLFile('ArrowHowto', globals())

    manage_about = HTMLFile('ArrowAbout', globals())  
    header_arrow = HTMLFile('ArrowHeader', globals())

    def manage_edit(self, body_arrow, title, trail, color_of_trail, text_family, text_size, text_spacing,text_delay, enable_arrow, REQUEST=None):
        """does this really need a doc string?"""
        self.body_arrow = body_arrow
	self.title = title
        self.trail = trail
        self.color_of_trail = color_of_trail
        self.text_family = text_family
        self.text_size = text_size
	self.text_spacing = text_spacing
	self.text_delay = text_delay
	self.enable_arrow = enable_arrow
	if REQUEST is not None:
	    return MessageDialog(
		title = 'Edited',
		message = "Properties for %s changed." % self.id,
		action = './manage_main',
		)
