# Documentation string. I wonder what ever refers to it? 

__doc__ = """Arrow initialization module. 

This module is used by App.ProductContext (or something else buried deep 
in the guts of Zope which ends up calling App.ProductContext) to provide 
product meta-data and perform any run-time initialization of a product 
that happens to be required. Since this product is Boring, all we're doing 
is defining the meta-data.

The product itself does NOT live in here. That's in ArrowAction.py.

See README.txt for more details."""

# Version string. Usually updated automatically by CVS. 

__version__ = '1.0' # Anything more and it'd be Interesting.  

# Step #1: import your Python class so we can refer to it later

import Arrow

# Step #2: define the initialize() function. 

def initialize(context): 
    """Initialize product.
    
    This function will be called by something (I've never bothered back-
    tracing it to find out) and provided with a ProductContext as an 
    argument. Our job is to call registerClass in that context in order 
    to provide information about our product.
    
    The try: except: trickery here is very, very handy when trying to 
    find out why your product isn't appearing in Control Panel, and was 
    pioneered -- as far as I can tell -- by jfarr@real.com in his LocalFS 
    Product. Thanks, j. 
    
    registerClass() can accept a lot more arguments than we're providing 
    here, but that wouldn't be Boring."""
    
    try: 
        """Try to register the product."""
        
        context.registerClass(
            
            Arrow.Arrow,         # Which is the addable bit? 
            
            constructors = (                 # The first of these is called 
                Arrow.manage_addArrowForm, # when someone adds the product; 
                Arrow.manage_addArrow),    # the second is named here so we 
                                             # can give people permission to 
                                             # call it. 
                                             
            icon = 'item.gif'                 
                                              
            )
       
    except:
        """If you can't register the product, tell someone. 
        
        Zope will sometimes provide you with access to "broken product" and
        a backtrace of what went wrong, but not always; I think that only 
        works for errors caught in your main product module. 
        
        This code provides traceback for anything that happened in 
        registerClass(), assuming you're running Zope in debug mode."""
        
        import sys, traceback, string
        type, val, tb = sys.exc_info()
        sys.stderr.write(string.join(traceback.format_exception(type, val, tb), ''))
        del type, val, tb
